@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -53,7 +53,7 @@
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include <locale.h>
+#include <clocale>
 #ifdef HAS_OPENBABEL_2
 #	include <openbabel/mol.h>
 #	include <openbabel/obconversion.h>
@@ -785,8 +785,8 @@ void gcpApplication::OnBug ()
 {
 	if (!WebBrowser.size ())
 		return;
-	char *argv[3] = {NULL, PACKAGE_BUGREPORT, NULL};
-	argv[0] = (char*) WebBrowser.c_str();
+	char *argv[3] = {NULL, const_cast<char*> (PACKAGE_BUGREPORT), NULL};
+	argv[0] = const_cast<char*> (WebBrowser.c_str());
 	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
 		NULL, NULL, NULL, NULL);
 }
@@ -795,7 +795,7 @@ void gcpApplication::OnWeb ()
 {
 	if (!WebBrowser.size ())
 		return;
-	char *argv[3] = {NULL, "http://www.nongnu.org/gchempaint", NULL};
+	char *argv[3] = {NULL, const_cast<char*> ("http://www.nongnu.org/gchempaint"), NULL};
 	argv[0] = (char*) WebBrowser.c_str();
 	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
 		NULL, NULL, NULL, NULL);
@@ -805,7 +805,7 @@ void gcpApplication::OnMail ()
 {
 	if (!MailAgent.size ())
 		return;
-	char *argv[3] = {NULL, "mailto:gchempaint-main@nongnu.org", NULL};
+	char *argv[3] = {NULL, const_cast<char*> ("mailto:gchempaint-main@nongnu.org"), NULL};
 	argv[0] = (char*) MailAgent.c_str();
 	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
 		NULL, NULL, NULL, NULL);
