@@ -4,9 +4,7 @@
  * GChemPaint library
  * dialog.h 
  *
- * Copyright (C) 2001-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,7 +26,7 @@
 #include "dialog.h"
 #include "application.h"
 #include <glib/gi18n.h>
-#include <string.h>
+#include <cstring>
 
 static void on_OK(GtkWidget *widget, gcpDialog* pBox)
 {
@@ -156,6 +154,8 @@ bool gcpDialog::GetNumber(GtkEntry *Entry, double *x, gcpCheckType c, double min
 			return false;
 		}
 		break;
+	default:
+		break;
 	}
 	return true;
 }
