@@ -4,7 +4,7 @@
  * GChemPaint library
  * document.cc 
  *
- * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -41,12 +41,12 @@
 #include "reaction.h"
 #include "mesomery.h"
 #include "text.h"
-#include <locale.h>
 #include <unistd.h>
 #include <libgen.h>
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
+#include <clocale>
 #ifdef HAS_OPENBABEL_2
 #	include <openbabel/mol.h>
 #	include <openbabel/obconversion.h>
@@ -540,7 +540,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 		xmlFree (tmp);
 	}
 
-	node = GetNodeByName (root, "title");
+	node = GetNodeByName (root, const_cast<char*> ("title"));
 	if (node)
 	{
 		tmp = (char*) xmlNodeGetContent (node);
@@ -549,7 +549,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 			xmlFree (tmp);
 		}
 	}
-	node = GetNodeByName (root, "author");
+	node = GetNodeByName (root, const_cast<char*> ("author"));
 	if (node)
 	{
 		tmp = (char*) xmlGetProp (node, (xmlChar*) "name");
@@ -563,7 +563,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 			xmlFree (tmp);
 		}
 	}
-	node = GetNodeByName (root, "comment");
+	node = GetNodeByName (root, const_cast<char*> ("comment"));
 	if (node)
 	{
 		tmp = (char*) xmlNodeGetContent (node);
@@ -1064,7 +1064,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 		child = child->next;
 	}
 	//Now, add bonds
-	child = GetNodeByName(node, "bond");
+	child = GetNodeByName(node, const_cast<char*> ("bond"));
 	while (child)
 	{
 		gcpBond* pBond = new gcpBond();
@@ -1072,7 +1072,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 		if (pBond->Load(child))
 			AddBond(pBond);
 		else delete pBond;
-		child = GetNextNodeByName(child->next, "bond");
+		child = GetNextNodeByName(child->next, const_cast<char*> ("bond"));
 	}
 }
 
