@@ -4,9 +4,7 @@
  * GChemPaint library
  * electron.cc
  *
- * Copyright (C) 2004-2006
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,7 +30,7 @@
 #include "widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
+#include <cmath>
 
 #define POSITION_NE 1
 #define POSITION_NW 2
@@ -223,11 +221,11 @@ void gcpElectron::SetSelected(GtkWidget* w, int state)
 	
 	switch (state)
 	{	
-		case SelStateUnselected: color = "black"; break;
+		case SelStateUnselected: color = const_cast<char*> ("black"); break;
 		case SelStateSelected: color = SelectColor; break;
 		case SelStateUpdating: color = AddColor; break;
 		case SelStateErasing: color = DeleteColor; break;
-		default: color = "black"; break;
+		default: color = const_cast<char*> ("black"); break;
 	}
 	g_object_set (G_OBJECT(g_object_get_data(G_OBJECT(group), "0")),
 				"fill_color", color, NULL);
@@ -243,31 +241,31 @@ xmlNodePtr gcpElectron::Save (xmlDocPtr xml)
 	if (m_Pos) {
 		switch (m_Pos) {
 		case POSITION_NE:
-			buf = "ne";
+			buf = const_cast<char*> ("ne");
 			break;
 		case POSITION_NW:
-			buf = "nw";
+			buf = const_cast<char*> ("nw");
 			break;
 		case POSITION_N:
-			buf = "n";
+			buf = const_cast<char*> ("n");
 			break;
 		case POSITION_SE:
-			buf = "se";
+			buf = const_cast<char*> ("se");
 			break;
 		case POSITION_SW:
-			buf = "sw";
+			buf = const_cast<char*> ("sw");
 			break;
 		case POSITION_S:
-			buf = "s";
+			buf = const_cast<char*> ("s");
 			break;
 		case POSITION_E:
-			buf = "e";
+			buf = const_cast<char*> ("e");
 			break;
 		case POSITION_W:
-			buf = "w";
+			buf = const_cast<char*> ("w");
 			break;
 		default:
-			buf = "def"; // should not occur
+			buf = const_cast<char*> ("def"); // should not occur
 		}
 		xmlNewProp (node, (xmlChar*) "position", (xmlChar*) buf);
 	} else {
