@@ -4,9 +4,7 @@
  * GChemPaint library
  * molecule.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -40,9 +38,9 @@
 #include "view.h"
 #include "application.h"
 #include "tool.h"
-#include <math.h>
 #include <unistd.h>
-#include <locale.h>
+#include <cmath>
+#include <clocale>
 #ifdef HAS_OPENBABEL_2
 #	include <openbabel/mol.h>
 #	include <openbabel/obconversion.h>
@@ -335,7 +333,7 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		SetId (buf);
 		xmlFree (buf);
 	}
-	child = GetNodeByName (node, "atom");
+	child = GetNodeByName (node, const_cast<char*> ("atom"));
 	while (child) {
 		pObject = new gcpAtom ();
 		if (pDoc)
@@ -347,10 +345,10 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		if (pDoc)
 			pDoc->AddAtom ((gcpAtom*) pObject);
 		AddAtom ((gcpAtom*) pObject);
-		child = GetNextNodeByName (child->next, "atom");
+		child = GetNextNodeByName (child->next, const_cast<char*> ("atom"));
 	}
 	
-	child = GetNodeByName (node, "fragment");
+	child = GetNodeByName (node, const_cast<char*> ("fragment"));
 	while (child) {
 		pObject = new gcpFragment ();
 		AddChild (pObject);
@@ -362,10 +360,10 @@ bool gcpMolecule::Load (xmlNodePtr node)
 			pDoc->AddFragment ((gcpFragment*) pObject);
 		AddFragment ((gcpFragment*) pObject);
 		((gcpFragment*) pObject)->AnalContent ();
-		child = GetNextNodeByName (child->next, "fragment");
+		child = GetNextNodeByName (child->next, const_cast<char*> ("fragment"));
 	}
 
-	child = GetNodeByName (node, "bond");
+	child = GetNodeByName (node, const_cast<char*> ("bond"));
 	while (child) {
 		pObject = new gcpBond ();
 		AddBond ((gcpBond*) pObject);
@@ -376,7 +374,7 @@ bool gcpMolecule::Load (xmlNodePtr node)
 		}
 		if (pDoc)
 			pDoc->AddBond ((gcpBond*) pObject);
-		child = GetNextNodeByName (child->next, "bond");
+		child = GetNextNodeByName (child->next, const_cast<char*> ("bond"));
 	}
 	if (!m_Atoms.empty ()) {
 		gcpAtom* pAtom = m_Atoms.front ();
