@@ -4,9 +4,7 @@
  * GChemPaint library
  * reaction-arrow.cc 
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,11 +31,11 @@
 #include "widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include "libgcpcanvas/gcp-canvas-line.h"
-#include <math.h>
+#include <cmath>
 
 gcpReactionArrow::gcpReactionArrow (gcpReaction* react, unsigned Type): gcpArrow (ReactionArrowType)
 {
-	SetId ("ra1");
+	SetId (const_cast<char*> ("ra1"));
 	m_Type = Type;
 	m_Start = m_End = NULL;
 	if (react) react->AddChild (this);
