@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-operator.cc 
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -30,7 +30,7 @@
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-text.h"
-#include <math.h>
+#include <cmath>
 
 gcpReactionOperator::gcpReactionOperator (): Object (ReactionOperatorType)
 {
