@@ -4,9 +4,7 @@
  * GChemPaint library
  * settings.cc 
  *
- * Copyright (C) 2001-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -43,11 +41,14 @@ double DefaultArrowPadding = 64.0;
 double DefaultStoichiometryPadding = 4.;
 double DefaultObjectPadding = 64.0;
 double DefaultSignPadding = 32.0;
-gchar* Color = "black";
-gchar* DeleteColor = "red";
-gchar* AddColor = "green";
-gchar* SelectColor = "cyan";
-gchar* DefaultFontFamily ="Bitstream Vera Sans";
+double ChargeSignHeight = 0.;
+double ChargeSignSize = 0.;
+double ChargeYAlign = 0.;
+gchar* Color = const_cast<char*> ("black");
+gchar* DeleteColor = const_cast<char*> ("red");
+gchar* AddColor = const_cast<char*> ("green");
+gchar* SelectColor = const_cast<char*> ("cyan");
+gchar* DefaultFontFamily = const_cast<char*> ("Bitstream Vera Sans");
 PangoStyle DefaultFontStyle = PANGO_STYLE_NORMAL;
 PangoWeight DefaultFontWeight = PANGO_WEIGHT_NORMAL;
 PangoVariant DefaultFontVariant = PANGO_VARIANT_NORMAL;
