@@ -4,9 +4,7 @@
  * GChemPaint library
  * view.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,12 +32,12 @@
 #include "text.h"
 #include "libgcpcanvas/gprintable.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
 #include <unistd.h>
 #include <pango/pango-context.h>
 #include <gdk/gdkkeysyms.h>
 #include <libgnomeprint/gnome-print-job.h>
-#include <locale.h>
+#include <cmath>
+#include <clocale>
 #include <fstream>
 
 /*
