@@ -4,9 +4,7 @@
  * GChemPaint arrows plugin
  * retrosynthesisarrow.cc
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,13 +30,13 @@
 #include "lib/widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-bpath.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
+#include <cmath>
 
 TypeId RetrosynthesisArrowType = NoType;
 
 gcpRetrosynthesisArrow::gcpRetrosynthesisArrow(gcpRetrosynthesis *rs): gcpArrow (RetrosynthesisArrowType)
 {
-	SetId ("rsa1");
+	SetId (const_cast<char*> ("rsa1"));
 	if (rs)
 		rs->AddChild( this);
 	m_Start = m_End = NULL;
