@@ -4,9 +4,7 @@
  * GChemPaint atoms plugin
  * elementtool.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -31,9 +29,9 @@
 #include "lib/settings.h"
 #include "lib/application.h"
 #include "lib/mendeleiev.h"
-#include <math.h>
-#include <string.h>
 #include "libgcpcanvas/gcp-canvas-group.h"
+#include <cmath>
+#include <cstring>
 
 gcpElementTool::gcpElementTool(gcpApplication *App): gcpTool(App, "Element")
 {
@@ -49,7 +47,7 @@ bool gcpElementTool::OnClicked()
 	if (m_pObject)
 	{
 		if (m_pObject->GetType() != AtomType) return false; 
-		if 	(((gcpAtom*)m_pObject)->GetTotalBondsNumber() > Element::GetMaxBonds(CurZ)) return false;
+		if 	(((gcpAtom*)m_pObject)->GetTotalBondsNumber() > (int) Element::GetMaxBonds(CurZ)) return false;
 		((gcpAtom*)m_pObject)->GetCoords(&m_x0, &m_y0);
 		m_x0 *= m_dZoomFactor;
 		m_y0 *= m_dZoomFactor;
