@@ -4,9 +4,7 @@
  * GChemPaint bonds plugin
  * bondtool.cc
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,7 +23,6 @@
  */
 
 #include "gchempaint-config.h"
-#include <math.h>
 #include "bondtool.h"
 #include "lib/settings.h"
 #include "lib/mendeleiev.h"
@@ -34,6 +31,7 @@
 #include "lib/atom.h"
 #include "lib/bond.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
+#include <cmath>
 
 gcpBondTool::gcpBondTool (gcpApplication *App, string ToolId, unsigned nPoints): gcpTool (App, ToolId)
 {
@@ -48,7 +46,6 @@ gcpBondTool::~gcpBondTool ()
 
 bool gcpBondTool::OnClicked ()
 {
-	double x1, y1, x2, y2;
 	int i;
 	m_pAtom = NULL;
 	m_pItem = NULL;
@@ -535,7 +532,6 @@ gcpDownBondTool::~gcpDownBondTool()
 void gcpDownBondTool::Draw()
 {
 	double dx, dy, dx1, dy1, length;
-	GnomeCanvasGroup* group;
 	m_pItem = gnome_canvas_item_new(m_pGroup, gnome_canvas_group_ext_get_type(), NULL);
 	length = sqrt(square(m_x1 - m_x0) + square(m_y1 - m_y0));
 	if (length == 0.0) return;
