@@ -4,7 +4,7 @@
  * GChemPaint cycles plugin
  * cycletool.cc 
  *
- * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,13 +28,13 @@
 #include "lib/mendeleiev.h"
 #include "lib/document.h"
 #include "lib/application.h"
-#include <math.h>
+#include <cmath>
 #include <list>
 #include <vector>
 
 using namespace std;
 
-static char* ToolNames [] = {
+static char const *ToolNames [] = {
 	"Cycle3",
 	"Cycle4",
 	"Cycle5",
