@@ -2,9 +2,7 @@
  * GChemPaint selection plugin
  * group.cc
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,7 +25,7 @@
 #include <lib/document.h>
 #include <lib/view.h>
 #include <lib/widgetdata.h>
-#include <math.h>
+#include <cmath>
 
 
 TypeId GroupType = NoType;
@@ -39,7 +37,7 @@ static void on_group_properties (gcpGroup* group)
 
 gcpGroup::gcpGroup (): Object(GroupType)
 {
-	SetId ("gr1");
+	SetId (const_cast<char*> ("gr1"));
 	m_Align = false;
 	m_Spaced = false;
 }
@@ -109,7 +107,7 @@ void gcpGroup::Align ()
 	Object* obj = GetFirstChild (i);
 	ArtDRect rect;
 	gcpView * View = ((gcpDocument*) GetDocument ())->GetView ();
-	double x, t;
+	double x = 0., t = 0.;
 	if ((m_AlignType == GCP_ALIGN_TOP) 
 		|| (m_AlignType == GCP_ALIGN_LEFT))
 		t = DBL_MAX;
@@ -270,28 +268,28 @@ xmlNodePtr gcpGroup::Save (xmlDocPtr xml)
 {
 	xmlNodePtr node = Object::Save (xml);
 	if (m_Align) {
-		char *align_type;
+		char *align_type = NULL;
 		switch (m_AlignType) {
 		case GCP_ALIGN_NORMAL:
-			align_type = "normal";
+			align_type = const_cast<char*> ("normal");
 			break;
 		case GCP_ALIGN_TOP:
-			align_type = "top";
+			align_type = const_cast<char*> ("top");
 			break;
 		case GCP_ALIGN_MID_HEIGHT:
-			align_type = "mid-height";
+			align_type = const_cast<char*> ("mid-height");
 			break;
 		case GCP_ALIGN_BOTTOM:
-			align_type = "bottom";
+			align_type = const_cast<char*> ("bottom");
 			break;
 		case GCP_ALIGN_LEFT:
-			align_type = "left";
+			align_type = const_cast<char*> ("left");
 			break;
 		case GCP_ALIGN_CENTER:
-			align_type = "center";
+			align_type = const_cast<char*> ("center");
 			break;
 		case GCP_ALIGN_RIGHT:
-			align_type = "right";
+			align_type = const_cast<char*> ("right");
 			break;
 		}
 		xmlNewProp (node, (const xmlChar*) "align", (const xmlChar*) align_type);
@@ -334,3 +332,14 @@ double gcpGroup::GetYAlign ()
 	pData->GetObjectBounds (this, &rect);
 	return (rect.y1 - rect.y0) / 2.;
 }
+
+void gcpGroup::Add (GtkWidget* w)
+{
+	map<string, Object*>::iterator i;
+	Object* p = GetFirstChild (i);
+	while (p)
+	{
+		p->Add (w);
+		p = GetNextChild (i);
+	}
+}
