@@ -99,7 +99,7 @@ gcpTemplatesPlugin::~gcpTemplatesPlugin()
 
 void gcpTemplatesPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (PKGDATADIR"/ui/templates.xml");
+	App->AddUI (GLADEDIR"/templates.xml");
 	new gcpTemplateTool (App);
 	new gcpTemplateTree (App);
 }
